# SmartFlow JS SDK

## 项目概述

SmartFlow JS SDK（以下简称SDK）是为了简化第三方应用客户端调用 SmartFlow 后端、基于 TypeScript 编写的、对部分 HTTP 请求的封装。使用 SDK 能够帮助第三方应用的前端开发人员简化开发流程，开发人员仅需要关注使用的方法、参数、返回值，而无需关注过多的细节。

## 如何使用

### 安装

该 SDK 并未发布到 npm 中央仓库，所以需要向项目的 `.npmrc` 配置文件中添加：

```properties
@rzdata:registry=https://git.rzdata.net/api/packages/rzdata/npm/
```

然后使用 npm 命令进行安装：

```shell
npm i -S @rzdata/smart-flow
```

### 使用

```js
// api/index.js
import { SmartFlowClient } from '@rzdata/smart-flow'

export const smartFlowClient = SmartFlowClient({
    baseURL: 'https://www.rzdata.net/smart-flow-api',
})

// 配置拦截器
smartFlowClient.instance.interceptors.request.use(
    (config) => {
        return config;
    }
)
// 配置拦截器
smartFlowClient.instance.interceptors.response.use(
    (config) => {
        return config;
    }
)
```

```vue
<script setup>
  import { smartFlowClient } from '@/api'
  import { onMounted } from "vue";
  
  const data = ref();

  onMounted(() => {
    smartFlowClient.execute.toDoPage({
      definitionId: '',  // 流程定义ID
    }, 1, 15)
        .then((response) => response.data)
        .then((pageResult) => pageResult.list)
        .then((list) => data.value = list)
  });
</script>
```

### 认证相关

SDK 可以通过以下方式进行认证：

#### `iv-user` 请求头

将用户名放入 `iv-user` 请求头。方法如下：

```js
smartFlowClient.instance.interceptors.request.use(
    (config) => {
        config.headers['iv-user'] = '<用户名>'
        return config;
    }
)
```

#### 睿展网关 SSO（推荐）

如果应用集成了睿展网关，并且经过了 SSO 登录，网关会自动添加 `iv-user` 请求头，SDK 无需进行额外处理。

#### JWT

`TODO` 该方案后续可能会有变动，暂不支持。
